@@ -31,6 +31,11 @@ from .cells import (
     line,
     is_res_class_iii,
     get_pentagon_indexes,
+    get_res0_indexes,
+    center_child,
+    get_faces,
+    experimental_h3_to_local_ij,
+    experimental_local_ij_to_h3,
 )
 
 from .edges import (
